==> org-lsst-sal-camera-2.1.0-sources.jar: org/lsst/sal/camera/event/EndOfImageTelemetryEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class EndOfImageTelemetryEvent extends CameraEvent {
  private final String imageType;

  private final String groupId;

  private final int imagesInSequence;

  private final String imageName;

  private final int imageIndex;

  private final String imageSource;

  private final String imageController;

  private final String imageDate;

  private final int imageNumber;

  private final double timeStampAcquisitionStart;

  private final double exposureTime;

  private final String imageTag;

  private final double timestampDateObs;

  private final double timestampDateEnd;

  private final double expTime;

  private final double darkTime;

  public EndOfImageTelemetryEvent(int priority, String imageType, String groupId,
      int imagesInSequence, String imageName, int imageIndex, String imageSource,
      String imageController, String imageDate, int imageNumber, double timeStampAcquisitionStart,
      double exposureTime, String imageTag, double timestampDateObs, double timestampDateEnd,
      double expTime, double darkTime) {
    super (priority);
    this.imageType = imageType;
    this.groupId = groupId;
    this.imagesInSequence = imagesInSequence;
    this.imageName = imageName;
    this.imageIndex = imageIndex;
    this.imageSource = imageSource;
    this.imageController = imageController;
    this.imageDate = imageDate;
    this.imageNumber = imageNumber;
    this.timeStampAcquisitionStart = timeStampAcquisitionStart;
    this.exposureTime = exposureTime;
    this.imageTag = imageTag;
    this.timestampDateObs = timestampDateObs;
    this.timestampDateEnd = timestampDateEnd;
    this.expTime = expTime;
    this.darkTime = darkTime;
  }

  public String getImageType() {
    return imageType;
  }

  public String getGroupId() {
    return groupId;
  }

  public int getImagesInSequence() {
    return imagesInSequence;
  }

  public String getImageName() {
    return imageName;
  }

  public int getImageIndex() {
    return imageIndex;
  }

  public String getImageSource() {
    return imageSource;
  }

  public String getImageController() {
    return imageController;
  }

  public String getImageDate() {
    return imageDate;
  }

  public int getImageNumber() {
    return imageNumber;
  }

  public double getTimeStampAcquisitionStart() {
    return timeStampAcquisitionStart;
  }

  public double getExposureTime() {
    return exposureTime;
  }

  public String getImageTag() {
    return imageTag;
  }

  public double getTimestampDateObs() {
    return timestampDateObs;
  }

  public double getTimestampDateEnd() {
    return timestampDateEnd;
  }

  public double getExpTime() {
    return expTime;
  }

  public double getDarkTime() {
    return darkTime;
  }

  @Override
  public String toString() {
    return "EndOfImageTelemetryEvent{" + "imageType=" + imageType +", groupId=" + groupId +
        ", imagesInSequence=" + imagesInSequence +", imageName=" + imageName +
        ", imageIndex=" + imageIndex +", imageSource=" + imageSource +
        ", imageController=" + imageController +", imageDate=" + imageDate +
        ", imageNumber=" + imageNumber +", timeStampAcquisitionStart=" + timeStampAcquisitionStart +
        ", exposureTime=" + exposureTime +", imageTag=" + imageTag +
        ", timestampDateObs=" + timestampDateObs +", timestampDateEnd=" + timestampDateEnd +
        ", expTime=" + expTime +", darkTime=" + darkTime +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String imageType;

    private String groupId;

    private int imagesInSequence;

    private String imageName;

    private int imageIndex;

    private String imageSource;

    private String imageController;

    private String imageDate;

    private int imageNumber;

    private double timeStampAcquisitionStart;

    private double exposureTime;

    private String imageTag;

    private double timestampDateObs;

    private double timestampDateEnd;

    private double expTime;

    private double darkTime;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder imageType(String imageType) {
      this.imageType = imageType;
      return this;
    }

    public Builder groupId(String groupId) {
      this.groupId = groupId;
      return this;
    }

    public Builder imagesInSequence(int imagesInSequence) {
      this.imagesInSequence = imagesInSequence;
      return this;
    }

    public Builder imageName(String imageName) {
      this.imageName = imageName;
      return this;
    }

    public Builder imageIndex(int imageIndex) {
      this.imageIndex = imageIndex;
      return this;
    }

    public Builder imageSource(String imageSource) {
      this.imageSource = imageSource;
      return this;
    }

    public Builder imageController(String imageController) {
      this.imageController = imageController;
      return this;
    }

    public Builder imageDate(String imageDate) {
      this.imageDate = imageDate;
      return this;
    }

    public Builder imageNumber(int imageNumber) {
      this.imageNumber = imageNumber;
      return this;
    }

    public Builder timeStampAcquisitionStart(double timeStampAcquisitionStart) {
      this.timeStampAcquisitionStart = timeStampAcquisitionStart;
      return this;
    }

    public Builder exposureTime(double exposureTime) {
      this.exposureTime = exposureTime;
      return this;
    }

    public Builder imageTag(String imageTag) {
      this.imageTag = imageTag;
      return this;
    }

    public Builder timestampDateObs(double timestampDateObs) {
      this.timestampDateObs = timestampDateObs;
      return this;
    }

    public Builder timestampDateEnd(double timestampDateEnd) {
      this.timestampDateEnd = timestampDateEnd;
      return this;
    }

    public Builder expTime(double expTime) {
      this.expTime = expTime;
      return this;
    }

    public Builder darkTime(double darkTime) {
      this.darkTime = darkTime;
      return this;
    }

    public EndOfImageTelemetryEvent build() {
      return new EndOfImageTelemetryEvent(priority, imageType, groupId, imagesInSequence, imageName, imageIndex, imageSource, imageController, imageDate, imageNumber, timeStampAcquisitionStart, exposureTime, imageTag, timestampDateObs, timestampDateEnd, expTime, darkTime);
    }
  }
}

==> org-lsst-sal-camera-2.1.2-sources.jar: org/lsst/sal/camera/event/EndOfImageTelemetryEvent.java <==
package org.lsst.sal.camera.event;

import org.lsst.sal.camera.CameraEvent;

public class EndOfImageTelemetryEvent extends CameraEvent {
  private final String imageType;

  private final String groupId;

  private final String additionalKeys;

  private final String additionalValues;

  private final int imagesInSequence;

  private final String imageName;

  private final int imageIndex;

  private final String imageSource;

  private final String imageController;

  private final String imageDate;

  private final int imageNumber;

  private final double timeStampAcquisitionStart;

  private final double exposureTime;

  private final String imageTag;

  private final double timestampDateObs;

  private final double timestampDateEnd;

  private final double expTime;

  private final double darkTime;

  public EndOfImageTelemetryEvent(int priority, String imageType, String groupId,
      String additionalKeys, String additionalValues, int imagesInSequence, String imageName,
      int imageIndex, String imageSource, String imageController, String imageDate, int imageNumber,
      double timeStampAcquisitionStart, double exposureTime, String imageTag,
      double timestampDateObs, double timestampDateEnd, double expTime, double darkTime) {
    super (priority);
    this.imageType = imageType;
    this.groupId = groupId;
    this.additionalKeys = additionalKeys;
    this.additionalValues = additionalValues;
    this.imagesInSequence = imagesInSequence;
    this.imageName = imageName;
    this.imageIndex = imageIndex;
    this.imageSource = imageSource;
    this.imageController = imageController;
    this.imageDate = imageDate;
    this.imageNumber = imageNumber;
    this.timeStampAcquisitionStart = timeStampAcquisitionStart;
    this.exposureTime = exposureTime;
    this.imageTag = imageTag;
    this.timestampDateObs = timestampDateObs;
    this.timestampDateEnd = timestampDateEnd;
    this.expTime = expTime;
    this.darkTime = darkTime;
  }

  public String getImageType() {
    return imageType;
  }

  public String getGroupId() {
    return groupId;
  }

  public String getAdditionalKeys() {
    return additionalKeys;
  }

  public String getAdditionalValues() {
    return additionalValues;
  }

  public int getImagesInSequence() {
    return imagesInSequence;
  }

  public String getImageName() {
    return imageName;
  }

  public int getImageIndex() {
    return imageIndex;
  }

  public String getImageSource() {
    return imageSource;
  }

  public String getImageController() {
    return imageController;
  }

  public String getImageDate() {
    return imageDate;
  }

  public int getImageNumber() {
    return imageNumber;
  }

  public double getTimeStampAcquisitionStart() {
    return timeStampAcquisitionStart;
  }

  public double getExposureTime() {
    return exposureTime;
  }

  public String getImageTag() {
    return imageTag;
  }

  public double getTimestampDateObs() {
    return timestampDateObs;
  }

  public double getTimestampDateEnd() {
    return timestampDateEnd;
  }

  public double getExpTime() {
    return expTime;
  }

  public double getDarkTime() {
    return darkTime;
  }

  @Override
  public String toString() {
    return "EndOfImageTelemetryEvent{" + "imageType=" + imageType +", groupId=" + groupId +
        ", additionalKeys=" + additionalKeys +", additionalValues=" + additionalValues +
        ", imagesInSequence=" + imagesInSequence +", imageName=" + imageName +
        ", imageIndex=" + imageIndex +", imageSource=" + imageSource +
        ", imageController=" + imageController +", imageDate=" + imageDate +
        ", imageNumber=" + imageNumber +", timeStampAcquisitionStart=" + timeStampAcquisitionStart +
        ", exposureTime=" + exposureTime +", imageTag=" + imageTag +
        ", timestampDateObs=" + timestampDateObs +", timestampDateEnd=" + timestampDateEnd +
        ", expTime=" + expTime +", darkTime=" + darkTime +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String imageType;

    private String groupId;

    private String additionalKeys;

    private String additionalValues;

    private int imagesInSequence;

    private String imageName;

    private int imageIndex;

    private String imageSource;

    private String imageController;

    private String imageDate;

    private int imageNumber;

    private double timeStampAcquisitionStart;

    private double exposureTime;

    private String imageTag;

    private double timestampDateObs;

    private double timestampDateEnd;

    private double expTime;

    private double darkTime;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder imageType(String imageType) {
      this.imageType = imageType;
      return this;
    }

    public Builder groupId(String groupId) {
      this.groupId = groupId;
      return this;
    }

    public Builder additionalKeys(String additionalKeys) {
      this.additionalKeys = additionalKeys;
      return this;
    }

    public Builder additionalValues(String additionalValues) {
      this.additionalValues = additionalValues;
      return this;
    }

    public Builder imagesInSequence(int imagesInSequence) {
      this.imagesInSequence = imagesInSequence;
      return this;
    }

    public Builder imageName(String imageName) {
      this.imageName = imageName;
      return this;
    }

    public Builder imageIndex(int imageIndex) {
      this.imageIndex = imageIndex;
      return this;
    }

    public Builder imageSource(String imageSource) {
      this.imageSource = imageSource;
      return this;
    }

    public Builder imageController(String imageController) {
      this.imageController = imageController;
      return this;
    }

    public Builder imageDate(String imageDate) {
      this.imageDate = imageDate;
      return this;
    }

    public Builder imageNumber(int imageNumber) {
      this.imageNumber = imageNumber;
      return this;
    }

    public Builder timeStampAcquisitionStart(double timeStampAcquisitionStart) {
      this.timeStampAcquisitionStart = timeStampAcquisitionStart;
      return this;
    }

    public Builder exposureTime(double exposureTime) {
      this.exposureTime = exposureTime;
      return this;
    }

    public Builder imageTag(String imageTag) {
      this.imageTag = imageTag;
      return this;
    }

    public Builder timestampDateObs(double timestampDateObs) {
      this.timestampDateObs = timestampDateObs;
      return this;
    }

    public Builder timestampDateEnd(double timestampDateEnd) {
      this.timestampDateEnd = timestampDateEnd;
      return this;
    }

    public Builder expTime(double expTime) {
      this.expTime = expTime;
      return this;
    }

    public Builder darkTime(double darkTime) {
      this.darkTime = darkTime;
      return this;
    }

    public EndOfImageTelemetryEvent build() {
      return new EndOfImageTelemetryEvent(priority, imageType, groupId, additionalKeys, additionalValues, imagesInSequence, imageName, imageIndex, imageSource, imageController, imageDate, imageNumber, timeStampAcquisitionStart, exposureTime, imageTag, timestampDateObs, timestampDateEnd, expTime, darkTime);
    }
  }
}
